/*!
 * @file network_node.h
 *  a class representing a node in the network (this can be a MASTER_SERVER, PROXY_SERVER or a CLIENT
 */

#ifndef _NETWORK_NODE_H
#define _NETWORK_NODE_H

#include "base_object.h"
#include "synchronizeable.h"

#include <list>

class PeerInfo;

//!< a class representing a node in the network (this can be a MASTER_SERVER, PROXY_SERVER or a CLIENT
class NetworkNode
{
  public:
    NetworkNode();
    ~NetworkNode();


    void addClient(PeerInfo* node);
    void addProxyServer(PeerInfo* node);
    void addMasterServer(PeerInfo* node);

    void removeClient(PeerInfo* node);
    void removeProxyServer(PeerInfo* node);
    void removeMasterServer(PeerInfo* node);

    /** @returns the number of players */
    inline int getPlayerNumber() { return this->playerNumber; }
    /** @returns the node type of this node */
    inline int getNodeType() { return this->nodeType; }


  private:
    int                          nodeType;                     //!< the type of the node
    int                          playerNumber;                 //!< localy direct connected player number

    /* network nodes directly connected to this node */
    std::list<PeerInfo*>         clientList;                   //!< list of all clients in the network
    std::list<PeerInfo*>         proxyServerList;              //!< list of all proxy servers in the network
    std::list<PeerInfo*>         masterServerList;             //!< list of all master servers in the network (should be 1!! :D)

};

#endif /* _NETWORK_NODE_H */
